function molbase_abnd,d0,t0,mol

; inverts the collision coefficient matrix to determine the 
; relative abundances.
; input:  d0    : density
;         t0    : temperature
;         mol   : molecule structure
; output: ncr   : critical density for transition mol.su
;         retval: abundance of lower level
; note  : in pcoll, the 1st index refers to columns, the second to rows.
;======================================================================

  amat   = fltarr(mol.nlev,mol.nlev)
  vec0   = fltarr(mol.nlev)
  indx   = lonarr(mol.nlev)

  vec0[0]   = d0
  amat[*,*] = (*(mol.pcoll))[*,*]

; fill lower triangle of collision matrix with c_lu (detailed balance)
  for j=0,mol.nlev-1 do begin
    for i=j+1,mol.nlev-1 do begin
      amat[j,i] = (2.0*i+1)/(2.0*j+1)*(*(mol.pcoll))[i,j]*exp(-4.798d-11*((*(mol.pener))[i]-(*(mol.pener))[j])/t0)
    endfor
  endfor
; compute critical density for transition mol.su. See e.g. Tielens, eq. 2.32
  (*(mol.ncr))[0] = (*(mol.peinst))[mol.su]/total(amat[mol.su-1,*])
; compute diagonal elements of collision matrix (after critical density...)
; This is the negative sum over the columns of pcoll.
  for i=0,mol.nlev-1 do begin
    amat[i,i] = -total(amat[i,*])
  endfor
; multiply the whole collision matrix with density
  amat[*,*] = amat[*,*] * d0
; and add the Einstein coefficients wherever appropriate...
  for i=1,mol.nlev-1 do begin
;   ...i.e. to the diagonal except [0,0]...
    amat[i,i]   = amat[i,i]   - (*(mol.peinst))[i]
;   ...and to the upper diagonal.
    amat[i,i-1] = amat[i,i-1] + (*(mol.peinst))[i]
  endfor  
; finally, replace the whole first row with 1's, to accommodate
; for condition sum(n_i) = n. The original first row is the sum of all
; remaining rows....
  amat[*,0] = 1.0
  la_ludc,amat,indx ; LR-decomposition 
  vec0[*] = la_lusol(amat,indx,vec0) ; matrix inversion
  return,vec0[mol.sl]

;======================================================================
end
